.. Aergo Herapy documentation master file, created by
   sphinx-quickstart on Thu Jan  3 11:40:57 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. _Aergo: http://github.com/aergoio/aergo
.. _HeraPy: http://github.com/aergoio/herapy


Welcome to Aergo HeraPy's documentation!
========================================

Aergo_ HeraPy_ is the Python SDK for communicating and interacting with the Aergo_ blockchain.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   intro
   getting_started
   how_to/index
   .. how_to_connect
   .. how_to_blockchain
   .. how_to_account
   .. how_to_transaction
   .. how_to_smart_contract


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
